@@ -928,7 +928,7 @@ static int init_VerifyFlags(SSLConfigRec *pConfig)
             return FALSE;
         }
 
-        ssl_log_own(pConfig, "CIPHER is %s", 
+        ssl_log_own(pConfig, "Cipher: %s", 
                     __SSLeay SSL_get_cipher(conn->client->ssl));
     }
 
