@@ -104,7 +104,6 @@
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <sys/un.h>
-#include <assert.h>
 #include <unistd.h>
 #include <string.h>
 
@@ -147,7 +146,6 @@ static int OpenServer()
         nSize = sizeof saServer.in;
     }
     else {
-        assert(strlen(szServerPort) < sizeof saServer.un.sun_path);
         saServer.un.sun_family = AF_UNIX;
         strcpy(saServer.un.sun_path, szServerPort);
         nSize = sizeof saServer.un;
@@ -155,7 +153,7 @@ static int OpenServer()
 
     if (connect(nSocket, (struct sockaddr *) &saServer, nSize)) {
         perror("connect");
-        assert(0);
+        exit(2);
     }
     return nSocket;
 }
